class Card < ActiveRecord::Base
  belongs_to :language

  validates_presence_of :language, :message => N_("%{fn} must be selected.")
  validates_presence_of :given_name, :message => N_("%{fn} cannot be blank.")

  file_column :photo, :magick => {
    :geometry => '480x480>',
    :versions => {
      'icon' => '20x20>',
      'small' => '50x50>',
    },
  }
  validates_filesize_of :photo, :in => 0..3.megabyte, :message => N_("Size of %{fn} is too huge.")

  def self.all_sorted(*args)
    with_scope(:find => { :order => 'sort_name, family_name, given_name, additional_name' }) {
      all(*args)
    }
  end

  def full_name
    case language.name
    when 'ja'
      [
        family_name, additional_name, given_name
      ].reject { |x| x.blank? }.join(' ')
    else
      [
        given_name, additional_name, family_name
      ].reject { |x| x.blank? }.join(' ')
    end
  end

  def delete_photo
    if @delete_photo.nil?
      false
    else
      @delete_photo
    end
  end

  def delete_photo=(value)
    if value == '1'
      self.photo = nil
      save!
      @delete_photo = true
    else
      @delete_photo = false
    end
  end
end
